/*
   The MIT License (MIT)
   -----------------------------------------------------------------------------

   Copyright (c) 2015 javafx.ninja <info@javafx.ninja>

   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to deal
   in the Software without restriction, including without limitation the rights
   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
   copies of the Software, and to permit persons to whom the Software is
   furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.

*/
package ninja.javafx.smartcsv.validation;

import groovy.lang.Binding;
import groovy.lang.GroovyShell;
import groovy.lang.Script;
import org.codehaus.groovy.control.CompilationFailedException;

/**
 * Executes the given groovy as check
 */
public class GroovyValidation extends EmptyValueIsValid {

    private String groovyScript;
    private GroovyShell shell = new GroovyShell();
    private Script script;

    public GroovyValidation(String groovyScript) {
        this.groovyScript = groovyScript;
        script = shell.parse(groovyScript);
    }


    @Override
    public void check(int row, String value, ValidationError error) {
        Binding binding = new Binding();
        binding.setVariable("value", value);
        script.setBinding(binding);

        Object groovyResult = null;
        try {
            groovyResult = script.run();
        } catch (CompilationFailedException e) {
            error.add("validation.message.groovy.exception", groovyScript, e.getMessage());
            e.printStackTrace();
        }
        if (groovyResult == null) {
            error.add("validation.message.groovy.return.null", groovyScript);
        }

        if (!isScriptResultTrue(groovyResult)) {
            error.add(groovyResult.toString());
        }
    }

    @Override
    public Type getType() {
        return Type.GROOVY;
    }

    private boolean isScriptResultTrue(Object groovyResult) {
        return groovyResult.equals(true) || groovyResult.toString().trim().toLowerCase().equals("true");
    }
}
